<?php
require_once 'functions.php';

// 处理登录
if (isset($_GET['login'])) {
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['password'])) {
        if ($_POST['password'] === ADMIN_PASSWORD) {
            $_SESSION['admin_logged_in'] = true;
            $_SESSION['login_time'] = time();
            header('Location: admin.php');
            exit;
        } else {
            $error = '密码错误';
        }
    }
    
    // 显示登录表单
    header('Content-Type: text/html; charset=utf-8');
    ?>
    <!DOCTYPE html>
    <html>
    <head>
        <title>活码系统 - 登录</title>
        <style>
            body { font-family: Arial, sans-serif; max-width: 500px; margin: 50px auto; padding: 20px; }
            h1 { text-align: center; }
            form { margin-top: 30px; }
            .form-group { margin-bottom: 20px; }
            label { display: block; margin-bottom: 5px; }
            input[type="password"] { padding: 10px; width: 100%; box-sizing: border-box; border: 1px solid #ddd; }
            input[type="submit"] { padding: 10px 20px; background: #4CAF50; color: white; border: none; cursor: pointer; width: 100%; }
            .error { color: red; text-align: center; margin-bottom: 20px; }
        </style>
    </head>
    <body>
        <h1>活码系统 - 登录</h1>
        <?php if (isset($error)) echo '<p class="error">' . $error . '</p>'; ?>
        <form method="post">
            <div class="form-group">
                <label for="password">密码:</label>
                <input type="password" id="password" name="password" required>
            </div>
            <div class="form-group">
                <input type="submit" value="登录">
            </div>
        </form>
    </body>
    </html>
    <?php
    exit;
}

// 检查登录状态
checkAdminLogin();

// 处理表单提交
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action']) && $_POST['action'] === 'upload' && !empty($_POST['name']) && isset($_FILES['image'])) {
        $result = handleImageUpload($_POST['name'], $_FILES['image']);
        $message = $result['message'];
    } elseif (isset($_POST['action']) && $_POST['action'] === 'delete' && !empty($_POST['name'])) {
        if (deleteImage($_POST['name'])) {
            $message = '活码 "' . htmlspecialchars($_POST['name']) . '" 已删除';
        } else {
            $message = '删除失败，活码可能不存在';
        }
    }
}

// 处理退出
if (isset($_GET['logout'])) {
    session_destroy();
    header('Location: admin.php?login');
    exit;
}

// 获取当前活码列表
$liveCodes = getLiveCodes();

// 显示管理页面
header('Content-Type: text/html; charset=utf-8');
?>
<!DOCTYPE html>
<html>
<head>
    <title>活码系统 - 管理</title>
    <style>
        body { font-family: Arial, sans-serif; max-width: 1000px; margin: 0 auto; padding: 20px; }
        .header { display: flex; justify-content: space-between; align-items: center; margin-bottom: 30px; }
        .message { padding: 15px; background: #f0f0f0; margin-bottom: 20px; border-radius: 4px; }
        .upload-form { background: #f9f9f9; padding: 20px; border-radius: 4px; margin-bottom: 30px; }
        .form-group { margin-bottom: 15px; }
        label { display: block; margin-bottom: 5px; font-weight: bold; }
        input[type="text"], input[type="file"] { padding: 10px; width: 100%; box-sizing: border-box; border: 1px solid #ddd; border-radius: 4px; }
        input[type="submit"], button { padding: 10px 20px; border: none; border-radius: 4px; cursor: pointer; }
        .btn-primary { background: #4CAF50; color: white; }
        .btn-danger { background: #f44336; color: white; }
        .btn-logout { background: #2196F3; color: white; }
        table { width: 100%; border-collapse: collapse; margin: 20px 0; }
        th, td { padding: 12px 15px; border: 1px solid #ddd; text-align: left; }
        th { background: #f5f5f5; }
        .code-img { max-width: 100px; max-height: 100px; display: block; }
        .code-url { width: 100%; padding: 8px; box-sizing: border-box; }
        .actions { display: flex; gap: 5px; }
    </style>
</head>
<body>
    <div class="header">
        <h1>活码系统 - 管理</h1>
        <a href="?logout" class="btn-logout">退出登录</a>
    </div>
    
    <?php if (!empty($message)): ?>
        <div class="message"><?php echo htmlspecialchars($message); ?></div>
    <?php endif; ?>
    
    <div class="upload-form">
        <h2>上传/更新活码</h2>
        <form method="post" enctype="multipart/form-data">
            <input type="hidden" name="action" value="upload">
            <div class="form-group">
                <label for="name">活码名称:</label>
                <input type="text" id="name" name="name" required placeholder="例如: 支付宝、微信等">
            </div>
            <div class="form-group">
                <label for="image">选择图片:</label>
                <input type="file" id="image" name="image" accept="image/*" required>
            </div>
            <div class="form-group">
                <input type="submit" value="上传/更新" class="btn-primary">
            </div>
        </form>
    </div>
    
    <h2>现有活码 (共 <?php echo count($liveCodes); ?> 个)</h2>
    <?php if (empty($liveCodes)): ?>
        <p>暂无活码</p>
    <?php else: ?>
        <table>
            <thead>
                <tr>
                    <th>名称</th>
                    <th>预览</th>
                    <th>链接</th>
                    <th>更新时间</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($liveCodes as $name => $code): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($name); ?></td>
                        <td><img src="<?php echo htmlspecialchars($code['url']); ?>" alt="<?php echo htmlspecialchars($name); ?>" class="code-img"></td>
                        <td>
                            <input type="text" class="code-url" value="<?php 
                                echo htmlspecialchars(
                                    'http://' . $_SERVER['HTTP_HOST'] . 
                                    dirname($_SERVER['SCRIPT_NAME']) . 
                                    '/index.php?name=' . 
                                    urlencode($name)
                                ); 
                            ?>" readonly>
                        </td>
                        <td><?php echo date('Y-m-d H:i:s', $code['time']); ?></td>
                        <td class="actions">
                            <form method="post" style="display: inline;">
                                <input type="hidden" name="action" value="delete">
                                <input type="hidden" name="name" value="<?php echo htmlspecialchars($name); ?>">
                                <button type="submit" class="btn-danger" onclick="return confirm('确定要删除这个活码吗？')">删除</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <?php endif; ?>
</body>
</html>