<?php
// 共用函数文件

// 配置信息
define('UPLOAD_DIR', __DIR__ . '/uploads/');
define('ADMIN_PASSWORD', 'admin123'); // 修改为你的管理密码

// 创建上传目录（如果不存在）
if (!file_exists(UPLOAD_DIR)) {
    mkdir(UPLOAD_DIR, 0777, true);
}

// 检查并创建.htaccess防止目录列表
$htaccess = UPLOAD_DIR . '.htaccess';
if (!file_exists($htaccess)) {
    file_put_contents($htaccess, "Options -Indexes\nDeny from all");
}

// 初始化会话
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

// 获取所有活码
function getLiveCodes() {
    $files = glob(UPLOAD_DIR . '*.{jpg,jpeg,png,gif,webp}', GLOB_BRACE);
    $liveCodes = [];
    
    foreach ($files as $file) {
        $name = pathinfo($file, PATHINFO_FILENAME);
        $liveCodes[$name] = [
            'path' => $file,
            'url' => 'uploads/' . basename($file),
            'time' => filemtime($file)
        ];
    }
    
    // 按名称排序
    ksort($liveCodes);
    
    return $liveCodes;
}

// 上传或更新图片
function handleImageUpload($name, $file) {
    // 验证名称
    if (!preg_match('/^[a-zA-Z0-9_\x{4e00}-\x{9fa5}]+$/u', $name)) {
        return ['success' => false, 'message' => '名称只能包含中文、英文、数字和下划线'];
    }
    
    // 验证文件
    if ($file['error'] !== UPLOAD_ERR_OK) {
        return ['success' => false, 'message' => '文件上传错误: ' . $file['error']];
    }
    
    // 检查文件类型
    $imageFileType = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
    if (!in_array($imageFileType, $allowed)) {
        return ['success' => false, 'message' => '只允许上传 JPG, JPEG, PNG, GIF 或 WEBP 文件。'];
    }
    
    // 检查是否是真实图片
    if (!getimagesize($file['tmp_name'])) {
        return ['success' => false, 'message' => '文件不是有效的图片。'];
    }
    
    // 生成唯一文件名
    $targetFile = UPLOAD_DIR . $name . '.' . $imageFileType;
    
    // 尝试移动文件
    if (move_uploaded_file($file['tmp_name'], $targetFile)) {
        // 删除同名的其他格式图片
        foreach ($allowed as $ext) {
            $oldFile = UPLOAD_DIR . $name . '.' . $ext;
            if ($oldFile != $targetFile && file_exists($oldFile)) {
                unlink($oldFile);
            }
        }
        return ['success' => true, 'message' => '文件上传成功。'];
    } else {
        return ['success' => false, 'message' => '文件上传失败，请检查目录权限。'];
    }
}

// 删除图片
function deleteImage($name) {
    $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
    $deleted = false;
    
    foreach ($allowed as $ext) {
        $file = UPLOAD_DIR . $name . '.' . $ext;
        if (file_exists($file)) {
            if (unlink($file)) {
                $deleted = true;
            }
        }
    }
    
    return $deleted;
}

// 检查管理员登录
function checkAdminLogin() {
    if (empty($_SESSION['admin_logged_in'])) {
        header('Location: admin.php?login');
        exit;
    }
}